@@ -6,7 +6,7 @@ pub mod config;
 pub mod stake_instruction;
 pub mod stake_state;
 
-solana_sdk::declare_id!("Stake11111111111111111111111111111111111111");
+pub use solana_sdk::stake::program::{check_id, id};
 
 pub fn add_genesis_accounts(genesis_config: &mut GenesisConfig) -> u64 {
     config::add_genesis_account(genesis_config)
